# Phidget22

[![Python version (Phidget22)](https://img.shields.io/pypi/v/Phidget22.svg?style=flat-square)](https://pypi.org/project/Phidget22/)

**Phidget22** is the official Python library for working with Phidgets in Python applications. It provides lightweight bindings to the native phidget22 library.


## Installation

### pip Package
The library is available as a pip package and includes the phidget22 native library for **Windows**, **Linux**, and **macOS**. For other operating systems, the native library must be installed separately.

### macOS Notes
- **HID USB Phidgets** require the installation of macOS libraries or the Standalone Control Panel ([Download Here](https://www.phidgets.com/docs/OS_-_macOS)).
  - HID USB Phidgets are listed as `'HID'` in the USB Stack field on their product page specifications tab at [www.phidgets.com](https://www.phidgets.com).
- **PHIDUSB, VINT Phidgets**: Newer USB Phidgets and VINT Phidgets do not require a separate install.


## Resources

- [Python Language Page](https://www.phidgets.com/docs/Language_-_Python)
- [Python API Reference](https://www.phidgets.com/?view=api&lang=Python)
- [Python Code Samples](https://www.phidgets.com/?view=code_samples&lang=Python)
